@@ -8,7 +8,7 @@ class RouteMeta:
 
     def __init__(self,
                  handler: FunctionType,
-                 func_args,
+                 handler_args,
                  route_id=None,
                  module=None,
                  name=None,
@@ -18,8 +18,8 @@ class RouteMeta:
                  kwargs=None):
         """
 
-        :param handler: 路由处理函数对象
-        :param func_args: 路由处理函数参数列表
+        :param handler: 路由函数对象
+        :param handler_args: 路由函数参数列表
         :param route_id: 路由ID，此ID由路由相关信息组合而成
         :param module: 装饰器上指定的 module 值
         :param name: 装饰器上指定的 name 值
@@ -27,7 +27,7 @@ class RouteMeta:
         :param kwargs: 装饰器上指定的其它参数
         """
         self.handler = handler
-        self.func_args = func_args
+        self.handler_args = handler_args
         self.id = route_id
         self.module = module
         self.name = name
@@ -51,4 +51,4 @@ class RouteMeta:
         :param arg_name:
         :return:
         """
-        return self.kwargs[arg_name] if arg_name in self.kwargs else default_value
+        return self.kwargs.get(arg_name, default_value)
